@@ -2,48 +2,54 @@ package Params::CallbackRequest::Exceptions;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '1.17';
+$VERSION = '1.18';
 
-use Exception::Class ( 'Params::Callback::Exception' =>
-		       { description => 'Params::Callback exception',
-                         alias       => 'throw_cb' },
+use Exception::Class (
+    'Params::Callback::Exception' => {
+        description => 'Params::Callback exception',
+        alias       => 'throw_cb'
+    },
 
-                       'Params::Callback::Exception::InvalidKey' =>
-		       { isa         => 'Params::Callback::Exception',
-                         description => 'No callback found for callback key',
-                         alias       => 'throw_bad_key',
-			 fields      => [ qw(callback_key) ] },
+    'Params::Callback::Exception::InvalidKey' => {
+        isa         => 'Params::Callback::Exception',
+        description => 'No callback found for callback key',
+        alias       => 'throw_bad_key',
+        fields      => [qw(callback_key)]
+    },
 
-                       'Params::Callback::Exception::Execution' =>
-		       { isa         => 'Params::Callback::Exception',
-                         description => 'Error thrown by callback',
-                         alias       => 'throw_cb_exec',
-			 fields      => [ qw(callback_key callback_error) ] },
+    'Params::Callback::Exception::Execution' => {
+        isa         => 'Params::Callback::Exception',
+        description => 'Error thrown by callback',
+        alias       => 'throw_cb_exec',
+        fields      => [qw(callback_key callback_error)]
+    },
 
-                       'Params::Callback::Exception::Params' =>
-		       { isa         => 'Params::Callback::Exception',
-                         description => 'Invalid parameter',
-                         alias       => 'throw_bad_params',
-			 fields      => [ qw(param) ] },
+    'Params::Callback::Exception::Params' => {
+        isa         => 'Params::Callback::Exception',
+        description => 'Invalid parameter',
+        alias       => 'throw_bad_params',
+        fields      => [qw(param)]
+    },
 
-                       'Params::Callback::Exception::Abort' =>
-                       { isa         => 'Params::Callback::Exception',
-                         fields      => [qw(aborted_value)],
-                         alias       => 'throw_abort',
-                         description => 'a callback called abort()' },
-		     );
+    'Params::Callback::Exception::Abort' => {
+        isa         => 'Params::Callback::Exception',
+        fields      => [qw(aborted_value)],
+        alias       => 'throw_abort',
+        description => 'a callback called abort()'
+    },
+);
 
 sub import {
     my ($class, %args) = @_;
 
     my $caller = caller;
     if ($args{abbr}) {
-	foreach my $name (@{$args{abbr}}) {
-	    no strict 'refs';
-	    die "Unknown exception abbreviation '$name'"
-              unless defined &{$name};
-	    *{"${caller}::$name"} = \&{$name};
-	}
+        foreach my $name (@{$args{abbr}}) {
+            no strict 'refs';
+            die "Unknown exception abbreviation '$name'"
+                unless defined &{$name};
+            *{"${caller}::$name"} = \&{$name};
+        }
     }
 
     no strict 'refs';
@@ -51,8 +57,6 @@ sub import {
     *{"${caller}::rethrow_exception"} = \&rethrow_exception;
 }
 
-
-
 sub isa_cb_exception ($;$) {
     my ($err, $name) = @_;
     return unless defined $err;
@@ -224,7 +228,7 @@ David Wheeler <david@kineticode.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2007 David Wheeler
+Copyright 2003-2008 David Wheeler. Some Rights Reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
